@@ -26,11 +26,27 @@
 #' table *are not* `NA` values or, in the database context, *not* `NULL` values.
 #' The validation function can be used directly on a data table or with an
 #' *agent* object (technically, a `ptblank_agent` object) whereas the
-#' expectation and test functions can only be used with a data table. The types
-#' of data tables that can be used include data frames, tibbles, database tables
-#' (`tbl_dbi`), and Spark DataFrames (`tbl_spark`). Each validation step or
-#' expectation will operate over the number of test units that is equal to the
-#' number of rows in the table (after any `preconditions` have been applied).
+#' expectation and test functions can only be used with a data table. Each
+#' validation step or expectation will operate over the number of test units
+#' that is equal to the number of rows in the table (after any `preconditions`
+#' have been applied).
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #'
 #' @section Column Names:
 #' If providing multiple column names, the result will be an expansion of
@@ -120,19 +136,23 @@
 #' as a validation step is expressed in R code and in the corresponding YAML
 #' representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_vals_not_null(
-#'     vars(a),
+#'     columns = vars(a),
 #'     preconditions = ~ . %>% dplyr::filter(a < 10),
 #'     segments = b ~ c("group_1", "group_2"),
 #'     actions = action_levels(warn_at = 0.1, stop_at = 0.2),
 #'     label = "The `col_vals_not_null()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_vals_not_null:
 #'     columns: vars(a)
@@ -161,10 +181,12 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #' 
-#' @examples
-#' # For all examples here, we'll use
-#' # a simple table with four columns:
-#' # `a`, `b`, `c`, and `d`
+#' @section Examples:
+#' 
+#' For all examples here, we'll use a simple table with four columns: `a`, `b`,
+#' `c`, and `d`.
+#' 
+#' ```{r}
 #' tbl <-
 #'   dplyr::tibble(
 #'     a = c( 5,  7,  6,  5,  8),
@@ -174,56 +196,61 @@
 #'   )
 #'   
 #' tbl
+#' ```
 #'   
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
 #' 
-#' # Validate that all values in column
-#' # `b` are *not* NA (they would be
-#' # non-NULL in a database context, which
-#' # isn't the case here)
+#' Validate that all values in column `b` are *not* NA (they would be non-`NULL`
+#' in a database context, which isn't the case here). We'll determine if this
+#' validation has any failing test units (there are 5 test units, one for each
+#' row).
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(tbl) %>%
-#'   col_vals_not_null(vars(b)) %>%
+#'   create_agent(tbl = tbl) %>%
+#'   col_vals_not_null(columns = vars(b)) %>%
 #'   interrogate()
+#' ```
 #' 
-#' # Determine if this validation
-#' # had no failing test units (there
-#' # are 5 test units, one for each row)
-#' all_passed(agent)
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_vals_not_null_1.png")`
+#' }
+#' }
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' ## B: Using the validation function directly on the data (no `agent`)
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' tbl %>%
-#'   col_vals_not_null(vars(b)) %>%
+#'   col_vals_not_null(columns = vars(b)) %>%
 #'   dplyr::pull(b)
+#' ```
 #'
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
-#' expect_col_vals_not_null(tbl, vars(b))
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
 #' 
-#' # D: Using the test function
+#' ```r
+#' expect_col_vals_not_null(tbl, columns = vars(b))
+#' ```
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
-#' tbl %>% test_col_vals_not_null(vars(b))
+#' ## D: Using the test function
+#' 
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
+#' tbl %>% test_col_vals_not_null(columns = vars(b))
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -237,15 +264,17 @@ NULL
 #' @rdname col_vals_not_null
 #' @import rlang
 #' @export
-col_vals_not_null <- function(x,
-                              columns,
-                              preconditions = NULL,
-                              segments = NULL,
-                              actions = NULL,
-                              step_id = NULL,
-                              label = NULL,
-                              brief = NULL,
-                              active = TRUE) {
+col_vals_not_null <- function(
+    x,
+    columns,
+    preconditions = NULL,
+    segments = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   values <- NULL
   
@@ -344,10 +373,12 @@ col_vals_not_null <- function(x,
 #' @rdname col_vals_not_null
 #' @import rlang
 #' @export
-expect_col_vals_not_null <- function(object,
-                                     columns,
-                                     preconditions = NULL,
-                                     threshold = 1) {
+expect_col_vals_not_null <- function(
+    object,
+    columns,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_vals_not_null"
   
@@ -418,10 +449,12 @@ expect_col_vals_not_null <- function(object,
 #' @rdname col_vals_not_null
 #' @import rlang
 #' @export
-test_col_vals_not_null <- function(object,
-                                   columns,
-                                   preconditions = NULL,
-                                   threshold = 1) {
+test_col_vals_not_null <- function(
+    object,
+    columns,
+    preconditions = NULL,
+    threshold = 1
+) {
 
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
