@@ -27,11 +27,26 @@
 #' available in the *Specifications* section). The validation function can be
 #' used directly on a data table or with an *agent* object (technically, a
 #' `ptblank_agent` object) whereas the expectation and test functions can only
-#' be used with a data table. The types of data tables that can be used include
-#' data frames, tibbles, database tables (`tbl_dbi`), and Spark DataFrames
-#' (`tbl_spark`). Each validation step or expectation will operate over the
-#' number of test units that is equal to the number of rows in the table (after
-#' any `preconditions` have been applied).
+#' be used with a data table. Each validation step or expectation will operate
+#' over the number of test units that is equal to the number of rows in the
+#' table (after any `preconditions` have been applied).
+#' 
+#' @section Supported Input Tables:
+#' The types of data tables that are officially supported are:
+#' 
+#'  - data frames (`data.frame`) and tibbles (`tbl_df`)
+#'  - Spark DataFrames (`tbl_spark`)
+#'  - the following database tables (`tbl_dbi`):
+#'    - *PostgreSQL* tables (using the `RPostgres::Postgres()` as driver)
+#'    - *MySQL* tables (with `RMySQL::MySQL()`)
+#'    - *Microsoft SQL Server* tables (via **odbc**)
+#'    - *BigQuery* tables (using `bigrquery::bigquery()`)
+#'    - *DuckDB* tables (through `duckdb::duckdb()`)
+#'    - *SQLite* (with `RSQLite::SQLite()`)
+#'    
+#' Other database tables may work to varying degrees but they haven't been
+#' formally tested (so be mindful of this when using unsupported backends with
+#' **pointblank**).
 #' 
 #' @section Specifications:
 #' A specification type must be used with the `spec` argument. This is a
@@ -174,8 +189,9 @@
 #' `col_vals_within_spec()` as a validation step is expressed in R code and in
 #' the corresponding YAML representation.
 #' 
-#' ```
-#' # R statement
+#' R statement:
+#' 
+#' ```r
 #' agent %>% 
 #'   col_vals_within_spec(
 #'     columns = vars(a),
@@ -187,8 +203,11 @@
 #'     label = "The `col_vals_within_spec()` step.",
 #'     active = FALSE
 #'   )
+#' ```
 #' 
-#' # YAML representation
+#' YAML representation:
+#' 
+#' ```yaml
 #' steps:
 #' - col_vals_within_spec:
 #'     columns: vars(a)
@@ -221,79 +240,86 @@
 #'   called primarily for its potential side-effects (e.g., signaling failure).
 #'   The test function returns a logical value.
 #' 
-#' @examples
-#' # The `specifications` dataset in the
-#' # package has columns of character data
-#' # that correspond to each of the
-#' # specifications that can be tested;
-#' # the following examples will validate
-#' # that the `email_addresses` column
-#' # has 5 correct values (this is true if
-#' # we get a subset of the data: the first
-#' # five rows)
+#' @section Examples:
+#' 
+#' The `specifications` dataset in the package has columns of character data
+#' that correspond to each of the specifications that can be tested. The
+#' following examples will validate that the `email_addresses` column has 5
+#' correct values (this is true if we get a subset of the data: the first five
+#' rows).
+#' 
+#' ```{r}
 #' spec_slice <- specifications[1:5, ]
 #' 
-#' # A: Using an `agent` with validation
-#' #    functions and then `interrogate()`
+#' spec_slice
+#' ```
 #' 
-#' # Validate that all values in the column
-#' # `email_addresses` are correct
+#' ## A: Using an `agent` with validation functions and then `interrogate()`
+#' 
+#' Validate that all values in the column `email_addresses` are correct. We'll
+#' determine if this validation has any failing test units (there are 5 test
+#' units, one for each row).
+#' 
+#' ```r
 #' agent <-
-#'   create_agent(spec_slice) %>%
+#'   create_agent(tbl = spec_slice) %>%
 #'   col_vals_within_spec(
-#'     vars(email_addresses),
+#'     columns = vars(email_addresses),
 #'     spec = "email"
 #'   ) %>%
 #'   interrogate()
-#'   
-#' # Determine if this validation
-#' # had no failing test units (there
-#' # are 5 test units, one for each row)
-#' all_passed(agent)
+#' ```
+#'
+#' Printing the `agent` in the console shows the validation report in the
+#' Viewer. Here is an excerpt of validation report, showing the single entry
+#' that corresponds to the validation step demonstrated here.
 #' 
-#' # Calling `agent` in the console
-#' # prints the agent's report; but we
-#' # can get a `gt_tbl` object directly
-#' # with `get_agent_report(agent)`
+#' \if{html}{
+#' \out{
+#' `r pb_get_image_tag(file = "man_col_vals_within_spec_1.png")`
+#' }
+#' }
 #' 
-#' # B: Using the validation function
-#' #    directly on the data (no `agent`)
+#' ## B: Using the validation function directly on the data (no `agent`)
 #' 
-#' # This way of using validation functions
-#' # acts as a data filter: data is passed
-#' # through but should `stop()` if there
-#' # is a single test unit failing; the
-#' # behavior of side effects can be
-#' # customized with the `actions` option
+#' This way of using validation functions acts as a data filter. Data is passed
+#' through but should `stop()` if there is a single test unit failing. The
+#' behavior of side effects can be customized with the `actions` option.
+#' 
+#' ```{r}
 #' spec_slice %>%
 #'   col_vals_within_spec(
-#'     vars(email_addresses),
+#'     columns = vars(email_addresses),
 #'     spec = "email"
 #'   ) %>%
 #'   dplyr::select(email_addresses)
+#' ```
 #'
-#' # C: Using the expectation function
+#' ## C: Using the expectation function
 #' 
-#' # With the `expect_*()` form, we would
-#' # typically perform one validation at a
-#' # time; this is primarily used in
-#' # testthat tests
+#' With the `expect_*()` form, we would typically perform one validation at a
+#' time. This is primarily used in **testthat** tests.
+#' 
+#' ```r
 #' expect_col_vals_within_spec(
 #'   spec_slice,
-#'   vars(email_addresses),
+#'   columns = vars(email_addresses),
 #'   spec = "email"
 #' )
+#' ```
 #' 
-#' # D: Using the test function
+#' ## D: Using the test function
 #' 
-#' # With the `test_*()` form, we should
-#' # get a single logical value returned
-#' # to us
+#' With the `test_*()` form, we should get a single logical value returned to
+#' us.
+#' 
+#' ```{r}
 #' spec_slice %>%
 #'   test_col_vals_within_spec(
-#'     vars(email_addresses),
+#'     columns = vars(email_addresses),
 #'     spec = "email"
 #'   )
+#' ```
 #' 
 #' @family validation functions
 #' @section Function ID:
@@ -305,17 +331,19 @@ NULL
 #' @rdname col_vals_within_spec
 #' @import rlang
 #' @export
-col_vals_within_spec <- function(x,
-                                 columns,
-                                 spec,
-                                 na_pass = FALSE,
-                                 preconditions = NULL,
-                                 segments = NULL,
-                                 actions = NULL,
-                                 step_id = NULL,
-                                 label = NULL,
-                                 brief = NULL,
-                                 active = TRUE) {
+col_vals_within_spec <- function(
+    x,
+    columns,
+    spec,
+    na_pass = FALSE,
+    preconditions = NULL,
+    segments = NULL,
+    actions = NULL,
+    step_id = NULL,
+    label = NULL,
+    brief = NULL,
+    active = TRUE
+) {
   
   # Get `columns` as a label
   columns_expr <- 
@@ -419,12 +447,14 @@ col_vals_within_spec <- function(x,
 #' @rdname col_vals_within_spec
 #' @import rlang
 #' @export
-expect_col_vals_within_spec <- function(object,
-                                        columns,
-                                        spec,
-                                        na_pass = FALSE,
-                                        preconditions = NULL,
-                                        threshold = 1) {
+expect_col_vals_within_spec <- function(
+    object,
+    columns,
+    spec,
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   fn_name <- "expect_col_vals_within_spec"
   
@@ -499,12 +529,14 @@ expect_col_vals_within_spec <- function(object,
 #' @rdname col_vals_within_spec
 #' @import rlang
 #' @export
-test_col_vals_within_spec <- function(object,
-                                      columns,
-                                      spec,
-                                      na_pass = FALSE,
-                                      preconditions = NULL,
-                                      threshold = 1) {
+test_col_vals_within_spec <- function(
+    object,
+    columns,
+    spec,
+    na_pass = FALSE,
+    preconditions = NULL,
+    threshold = 1
+) {
   
   vs <- 
     create_agent(tbl = object, label = "::QUIET::") %>%
