@@ -1530,11 +1530,23 @@ probe_sample <- function(data) {
       fn = function(x) ifelse(x == "**NA**", "<code>NA</code>", x)
     ) %>%
     gt::tab_options(table.width = "100%") %>% 
-    gt::tab_style(style = gt::cell_text(font = "monospace"),
-      locations = list(gt::cells_column_labels(), gt::cells_body())) %>% 
-    gt::text_transform(locations = gt::cells_body(), 
-      fn = function(x) {ifelse(x == "<code>NA</code>",
-        "<code style=\"color:#3A70FB\">NA</code>", x)})
+    gt::tab_style(
+      style = gt::cell_text(font = "monospace"),
+      locations = list(
+        gt::cells_column_labels(),
+        gt::cells_body()
+      )
+    ) %>% 
+    gt::text_transform(
+      locations = gt::cells_body(), 
+      fn = function(x) {
+        ifelse(
+          x == "<code>NA</code>",
+          "<code style=\"color:#3A70FB\">NA</code>",
+          x
+        )
+      }
+    )
   
   list(probe_sample = probe_sample)
 }
