@@ -1056,7 +1056,7 @@ test_that("Creating a `row_count_match()` step is possible", {
   # Use `row_count_match()` function to create a validation step
   validation <-
     create_agent(tbl = small_table) %>%
-    row_count_match(tbl_compare = small_table)
+    row_count_match(count = small_table)
   expect_is(validation, "ptblank_agent")
   
   # Expect elements of the object to be equivalent
@@ -1075,21 +1075,90 @@ test_that("Creating a `row_count_match()` step is possible", {
   # Use different inputs for `tbl` in `row_count_match()`
   validation <-
     create_agent(tbl = small_table) %>%
-    row_count_match(tbl_compare = ~ small_table)
+    row_count_match(count = ~ small_table)
   expect_is(validation, "ptblank_agent")
   expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
   
   validation <-
     create_agent(tbl = small_table) %>%
-    row_count_match(tbl_compare = small_table ~ pointblank::small_table)
+    row_count_match(count = small_table ~ pointblank::small_table)
   expect_is(validation, "ptblank_agent")
   expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
   
   validation <-
     create_agent(tbl = small_table) %>%
-    row_count_match(tbl_compare = function() small_table)
+    row_count_match(count = function() small_table)
   expect_is(validation, "ptblank_agent")
   expect_true(is.function(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    row_count_match(count = 13)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.numeric(validation$validation_set[["values"]][[1]]))
+  expect_equal(validation$validation_set[["values"]][[1]], 13)
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    row_count_match(count = 13L)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.numeric(validation$validation_set[["values"]][[1]]))
+  expect_equal(validation$validation_set[["values"]][[1]], 13)
+})
+
+test_that("Creating a `col_count_match()` step is possible", {
+  
+  # Use `col_count_match()` function to create a validation step
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_count_match(count = small_table)
+  expect_is(validation, "ptblank_agent")
+  
+  # Expect elements of the object to be equivalent
+  # to specific parameters
+  expect_true(inherits(validation$validation_set[["values"]][[1]], "tbl_df"))
+  expect_true(is.na(validation$validation_set$all_passed))
+  expect_true(is.na(validation$validation_set$n))
+  expect_true(is.na(validation$validation_set$n_passed))
+  expect_true(is.na(validation$validation_set$n_failed))
+  expect_true(is.na(validation$validation_set$f_passed))
+  expect_true(is.na(validation$validation_set$f_failed))
+  expect_true(is.na(validation$validation_set$warn))
+  expect_true(is.na(validation$validation_set$notify))
+  expect_true(is.na(validation$validation_set$row_sample))
+  
+  # Use different inputs for `tbl` in `col_count_match()`
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_count_match(count = ~ small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_count_match(count = small_table ~ pointblank::small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(rlang::is_formula(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_count_match(count = function() small_table)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.function(validation$validation_set[["values"]][[1]]))
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_count_match(count = 8)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.numeric(validation$validation_set[["values"]][[1]]))
+  expect_equal(validation$validation_set[["values"]][[1]], 8)
+  
+  validation <-
+    create_agent(tbl = small_table) %>%
+    col_count_match(count = 8L)
+  expect_is(validation, "ptblank_agent")
+  expect_true(is.numeric(validation$validation_set[["values"]][[1]]))
+  expect_equal(validation$validation_set[["values"]][[1]], 8)
 })
 
 test_that("Creating a `tbl_match()` step is possible", {
