@@ -107,10 +107,10 @@ test_that("A table store object can be created and used effectively", {
   expect_equal(tbl_formula_chr[2], "some_specifications")
   expect_equal(tbl_formula_chr[3], "specifications %>% dplyr::select(zip_codes, credit_card_numbers, email_addresses)")
   
-  # Expect the `tbl_formula` to be compatible with the `read_fn` argument in
+  # Expect the `tbl_formula` to be compatible with the `tbl` argument in
   # `create_agent()` and `create_informant()`
-  expect_error(regexp = NA, create_agent(read_fn = tbl_formula))
-  expect_error(regexp = NA, create_informant(read_fn = tbl_formula))
+  expect_error(regexp = NA, create_agent(tbl = tbl_formula))
+  expect_error(regexp = NA, create_informant(tbl = tbl_formula))
   
   # Materialize all tables from the `tbls` table store with `tbl_get()`
   tbl_small_tbl_duckdb <- tbl_get(tbl = "small_tbl_duckdb", store = tbls)
